# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as

from ..models import ApiAMSRegionsResponse
from ..models import ApiInstanceTypesForNamespaceResponse
from ..models import ResponseErrorResponse

from ..operations.ams_info import InfoRegions
from ..operations.ams_info import InfoSupportedInstances
from ..operations.ams_info import UploadURLGet


@same_doc_as(InfoRegions)
def info_regions(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get a list of the available AMS regions (InfoRegions)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/regions

        method: GET

        tags: ["AMS Info"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiAMSRegionsResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = InfoRegions.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(InfoRegions)
async def info_regions_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get a list of the available AMS regions (InfoRegions)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/regions

        method: GET

        tags: ["AMS Info"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiAMSRegionsResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = InfoRegions.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(InfoSupportedInstances)
def info_supported_instances(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get a list of available VM configurations (InfoSupportedInstances)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/supported-instances

        method: GET

        tags: ["AMS Info"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiInstanceTypesForNamespaceResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = InfoSupportedInstances.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(InfoSupportedInstances)
async def info_supported_instances_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """get a list of available VM configurations (InfoSupportedInstances)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/supported-instances

        method: GET

        tags: ["AMS Info"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiInstanceTypesForNamespaceResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = InfoSupportedInstances.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UploadURLGet)
def upload_url_get(x_additional_headers: Optional[Dict[str, str]] = None, **kwargs):
    """get an URL for uploading an image (UploadURLGet)


    Properties:
        url: /ams/v1/upload-url

        method: GET

        tags: ["AMS Info"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (success)
    """
    request = UploadURLGet.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UploadURLGet)
async def upload_url_get_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """get an URL for uploading an image (UploadURLGet)


    Properties:
        url: /ams/v1/upload-url

        method: GET

        tags: ["AMS Info"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - (success)
    """
    request = UploadURLGet.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class TimeZoneTrans(Model):
    """Time zone trans (time.zoneTrans)

    Properties:
        index: (index) REQUIRED int

        isstd: (isstd) REQUIRED bool

        isutc: (isutc) REQUIRED bool

        when: (when) REQUIRED int
    """

    # region fields

    index: int  # REQUIRED
    isstd: bool  # REQUIRED
    isutc: bool  # REQUIRED
    when: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_index(self, value: int) -> TimeZoneTrans:
        self.index = value
        return self

    def with_isstd(self, value: bool) -> TimeZoneTrans:
        self.isstd = value
        return self

    def with_isutc(self, value: bool) -> TimeZoneTrans:
        self.isutc = value
        return self

    def with_when(self, value: int) -> TimeZoneTrans:
        self.when = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "index"):
            result["index"] = int(self.index)
        elif include_empty:
            result["index"] = 0
        if hasattr(self, "isstd"):
            result["isstd"] = bool(self.isstd)
        elif include_empty:
            result["isstd"] = False
        if hasattr(self, "isutc"):
            result["isutc"] = bool(self.isutc)
        elif include_empty:
            result["isutc"] = False
        if hasattr(self, "when"):
            result["when"] = int(self.when)
        elif include_empty:
            result["when"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, index: int, isstd: bool, isutc: bool, when: int, **kwargs
    ) -> TimeZoneTrans:
        instance = cls()
        instance.index = index
        instance.isstd = isstd
        instance.isutc = isutc
        instance.when = when
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> TimeZoneTrans:
        instance = cls()
        if not dict_:
            return instance
        if "index" in dict_ and dict_["index"] is not None:
            instance.index = int(dict_["index"])
        elif include_empty:
            instance.index = 0
        if "isstd" in dict_ and dict_["isstd"] is not None:
            instance.isstd = bool(dict_["isstd"])
        elif include_empty:
            instance.isstd = False
        if "isutc" in dict_ and dict_["isutc"] is not None:
            instance.isutc = bool(dict_["isutc"])
        elif include_empty:
            instance.isutc = False
        if "when" in dict_ and dict_["when"] is not None:
            instance.when = int(dict_["when"])
        elif include_empty:
            instance.when = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, TimeZoneTrans]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[TimeZoneTrans]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[TimeZoneTrans, List[TimeZoneTrans], Dict[Any, TimeZoneTrans]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "index": "index",
            "isstd": "isstd",
            "isutc": "isutc",
            "when": "when",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "index": True,
            "isstd": True,
            "isutc": True,
            "when": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ApiArtifactResponse(Model):
    """Api artifact response (api.ArtifactResponse)

    Properties:
        artifact_type: (artifactType) REQUIRED str

        created_on: (createdOn) REQUIRED str

        ds_id: (dsId) REQUIRED str

        expires_on: (expiresOn) REQUIRED str

        filename: (filename) REQUIRED str

        fleet_id: (fleetId) REQUIRED str

        id_: (id) REQUIRED str

        image_id: (imageId) REQUIRED str

        namespace: (namespace) REQUIRED str

        region: (region) REQUIRED str

        size_bytes: (sizeBytes) REQUIRED int

        status: (status) REQUIRED str
    """

    # region fields

    artifact_type: str  # REQUIRED
    created_on: str  # REQUIRED
    ds_id: str  # REQUIRED
    expires_on: str  # REQUIRED
    filename: str  # REQUIRED
    fleet_id: str  # REQUIRED
    id_: str  # REQUIRED
    image_id: str  # REQUIRED
    namespace: str  # REQUIRED
    region: str  # REQUIRED
    size_bytes: int  # REQUIRED
    status: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_artifact_type(self, value: str) -> ApiArtifactResponse:
        self.artifact_type = value
        return self

    def with_created_on(self, value: str) -> ApiArtifactResponse:
        self.created_on = value
        return self

    def with_ds_id(self, value: str) -> ApiArtifactResponse:
        self.ds_id = value
        return self

    def with_expires_on(self, value: str) -> ApiArtifactResponse:
        self.expires_on = value
        return self

    def with_filename(self, value: str) -> ApiArtifactResponse:
        self.filename = value
        return self

    def with_fleet_id(self, value: str) -> ApiArtifactResponse:
        self.fleet_id = value
        return self

    def with_id(self, value: str) -> ApiArtifactResponse:
        self.id_ = value
        return self

    def with_image_id(self, value: str) -> ApiArtifactResponse:
        self.image_id = value
        return self

    def with_namespace(self, value: str) -> ApiArtifactResponse:
        self.namespace = value
        return self

    def with_region(self, value: str) -> ApiArtifactResponse:
        self.region = value
        return self

    def with_size_bytes(self, value: int) -> ApiArtifactResponse:
        self.size_bytes = value
        return self

    def with_status(self, value: str) -> ApiArtifactResponse:
        self.status = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "artifact_type"):
            result["artifactType"] = str(self.artifact_type)
        elif include_empty:
            result["artifactType"] = ""
        if hasattr(self, "created_on"):
            result["createdOn"] = str(self.created_on)
        elif include_empty:
            result["createdOn"] = ""
        if hasattr(self, "ds_id"):
            result["dsId"] = str(self.ds_id)
        elif include_empty:
            result["dsId"] = ""
        if hasattr(self, "expires_on"):
            result["expiresOn"] = str(self.expires_on)
        elif include_empty:
            result["expiresOn"] = ""
        if hasattr(self, "filename"):
            result["filename"] = str(self.filename)
        elif include_empty:
            result["filename"] = ""
        if hasattr(self, "fleet_id"):
            result["fleetId"] = str(self.fleet_id)
        elif include_empty:
            result["fleetId"] = ""
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "image_id"):
            result["imageId"] = str(self.image_id)
        elif include_empty:
            result["imageId"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "region"):
            result["region"] = str(self.region)
        elif include_empty:
            result["region"] = ""
        if hasattr(self, "size_bytes"):
            result["sizeBytes"] = int(self.size_bytes)
        elif include_empty:
            result["sizeBytes"] = 0
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        artifact_type: str,
        created_on: str,
        ds_id: str,
        expires_on: str,
        filename: str,
        fleet_id: str,
        id_: str,
        image_id: str,
        namespace: str,
        region: str,
        size_bytes: int,
        status: str,
        **kwargs,
    ) -> ApiArtifactResponse:
        instance = cls()
        instance.artifact_type = artifact_type
        instance.created_on = created_on
        instance.ds_id = ds_id
        instance.expires_on = expires_on
        instance.filename = filename
        instance.fleet_id = fleet_id
        instance.id_ = id_
        instance.image_id = image_id
        instance.namespace = namespace
        instance.region = region
        instance.size_bytes = size_bytes
        instance.status = status
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiArtifactResponse:
        instance = cls()
        if not dict_:
            return instance
        if "artifactType" in dict_ and dict_["artifactType"] is not None:
            instance.artifact_type = str(dict_["artifactType"])
        elif include_empty:
            instance.artifact_type = ""
        if "createdOn" in dict_ and dict_["createdOn"] is not None:
            instance.created_on = str(dict_["createdOn"])
        elif include_empty:
            instance.created_on = ""
        if "dsId" in dict_ and dict_["dsId"] is not None:
            instance.ds_id = str(dict_["dsId"])
        elif include_empty:
            instance.ds_id = ""
        if "expiresOn" in dict_ and dict_["expiresOn"] is not None:
            instance.expires_on = str(dict_["expiresOn"])
        elif include_empty:
            instance.expires_on = ""
        if "filename" in dict_ and dict_["filename"] is not None:
            instance.filename = str(dict_["filename"])
        elif include_empty:
            instance.filename = ""
        if "fleetId" in dict_ and dict_["fleetId"] is not None:
            instance.fleet_id = str(dict_["fleetId"])
        elif include_empty:
            instance.fleet_id = ""
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "imageId" in dict_ and dict_["imageId"] is not None:
            instance.image_id = str(dict_["imageId"])
        elif include_empty:
            instance.image_id = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "region" in dict_ and dict_["region"] is not None:
            instance.region = str(dict_["region"])
        elif include_empty:
            instance.region = ""
        if "sizeBytes" in dict_ and dict_["sizeBytes"] is not None:
            instance.size_bytes = int(dict_["sizeBytes"])
        elif include_empty:
            instance.size_bytes = 0
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiArtifactResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiArtifactResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiArtifactResponse, List[ApiArtifactResponse], Dict[Any, ApiArtifactResponse]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "artifactType": "artifact_type",
            "createdOn": "created_on",
            "dsId": "ds_id",
            "expiresOn": "expires_on",
            "filename": "filename",
            "fleetId": "fleet_id",
            "id": "id_",
            "imageId": "image_id",
            "namespace": "namespace",
            "region": "region",
            "sizeBytes": "size_bytes",
            "status": "status",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "artifactType": True,
            "createdOn": True,
            "dsId": True,
            "expiresOn": True,
            "filename": True,
            "fleetId": True,
            "id": True,
            "imageId": True,
            "namespace": True,
            "region": True,
            "sizeBytes": True,
            "status": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.time_location import TimeLocation


class ApiTime(Model):
    """Api time (api.Time)

    Properties:
        ext: (ext) REQUIRED int

        loc: (loc) REQUIRED TimeLocation

        wall: (wall) REQUIRED int
    """

    # region fields

    ext: int  # REQUIRED
    loc: TimeLocation  # REQUIRED
    wall: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_ext(self, value: int) -> ApiTime:
        self.ext = value
        return self

    def with_loc(self, value: TimeLocation) -> ApiTime:
        self.loc = value
        return self

    def with_wall(self, value: int) -> ApiTime:
        self.wall = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "ext"):
            result["ext"] = int(self.ext)
        elif include_empty:
            result["ext"] = 0
        if hasattr(self, "loc"):
            result["loc"] = self.loc.to_dict(include_empty=include_empty)
        elif include_empty:
            result["loc"] = TimeLocation()
        if hasattr(self, "wall"):
            result["wall"] = int(self.wall)
        elif include_empty:
            result["wall"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(cls, ext: int, loc: TimeLocation, wall: int, **kwargs) -> ApiTime:
        instance = cls()
        instance.ext = ext
        instance.loc = loc
        instance.wall = wall
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ApiTime:
        instance = cls()
        if not dict_:
            return instance
        if "ext" in dict_ and dict_["ext"] is not None:
            instance.ext = int(dict_["ext"])
        elif include_empty:
            instance.ext = 0
        if "loc" in dict_ and dict_["loc"] is not None:
            instance.loc = TimeLocation.create_from_dict(
                dict_["loc"], include_empty=include_empty
            )
        elif include_empty:
            instance.loc = TimeLocation()
        if "wall" in dict_ and dict_["wall"] is not None:
            instance.wall = int(dict_["wall"])
        elif include_empty:
            instance.wall = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiTime]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiTime]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[ApiTime, List[ApiTime], Dict[Any, ApiTime]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "ext": "ext",
            "loc": "loc",
            "wall": "wall",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "ext": True,
            "loc": True,
            "wall": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.api_fleet_regional_server_counts import ApiFleetRegionalServerCounts


class ApiFleetListItemResponse(Model):
    """Api fleet list item response (api.FleetListItemResponse)

    Properties:
        active: (active) REQUIRED bool

        counts: (counts) REQUIRED List[ApiFleetRegionalServerCounts]

        id_: (id) REQUIRED str

        image: (image) REQUIRED str

        instance_provider: (instanceProvider) REQUIRED str

        is_local: (isLocal) REQUIRED bool

        name: (name) REQUIRED str

        on_demand: (onDemand) REQUIRED bool

        regions: (regions) REQUIRED List[str]
    """

    # region fields

    active: bool  # REQUIRED
    counts: List[ApiFleetRegionalServerCounts]  # REQUIRED
    id_: str  # REQUIRED
    image: str  # REQUIRED
    instance_provider: str  # REQUIRED
    is_local: bool  # REQUIRED
    name: str  # REQUIRED
    on_demand: bool  # REQUIRED
    regions: List[str]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_active(self, value: bool) -> ApiFleetListItemResponse:
        self.active = value
        return self

    def with_counts(
        self, value: List[ApiFleetRegionalServerCounts]
    ) -> ApiFleetListItemResponse:
        self.counts = value
        return self

    def with_id(self, value: str) -> ApiFleetListItemResponse:
        self.id_ = value
        return self

    def with_image(self, value: str) -> ApiFleetListItemResponse:
        self.image = value
        return self

    def with_instance_provider(self, value: str) -> ApiFleetListItemResponse:
        self.instance_provider = value
        return self

    def with_is_local(self, value: bool) -> ApiFleetListItemResponse:
        self.is_local = value
        return self

    def with_name(self, value: str) -> ApiFleetListItemResponse:
        self.name = value
        return self

    def with_on_demand(self, value: bool) -> ApiFleetListItemResponse:
        self.on_demand = value
        return self

    def with_regions(self, value: List[str]) -> ApiFleetListItemResponse:
        self.regions = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "active"):
            result["active"] = bool(self.active)
        elif include_empty:
            result["active"] = False
        if hasattr(self, "counts"):
            result["counts"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.counts
            ]
        elif include_empty:
            result["counts"] = []
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "image"):
            result["image"] = str(self.image)
        elif include_empty:
            result["image"] = ""
        if hasattr(self, "instance_provider"):
            result["instanceProvider"] = str(self.instance_provider)
        elif include_empty:
            result["instanceProvider"] = ""
        if hasattr(self, "is_local"):
            result["isLocal"] = bool(self.is_local)
        elif include_empty:
            result["isLocal"] = False
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "on_demand"):
            result["onDemand"] = bool(self.on_demand)
        elif include_empty:
            result["onDemand"] = False
        if hasattr(self, "regions"):
            result["regions"] = [str(i0) for i0 in self.regions]
        elif include_empty:
            result["regions"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        active: bool,
        counts: List[ApiFleetRegionalServerCounts],
        id_: str,
        image: str,
        instance_provider: str,
        is_local: bool,
        name: str,
        on_demand: bool,
        regions: List[str],
        **kwargs,
    ) -> ApiFleetListItemResponse:
        instance = cls()
        instance.active = active
        instance.counts = counts
        instance.id_ = id_
        instance.image = image
        instance.instance_provider = instance_provider
        instance.is_local = is_local
        instance.name = name
        instance.on_demand = on_demand
        instance.regions = regions
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiFleetListItemResponse:
        instance = cls()
        if not dict_:
            return instance
        if "active" in dict_ and dict_["active"] is not None:
            instance.active = bool(dict_["active"])
        elif include_empty:
            instance.active = False
        if "counts" in dict_ and dict_["counts"] is not None:
            instance.counts = [
                ApiFleetRegionalServerCounts.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["counts"]
            ]
        elif include_empty:
            instance.counts = []
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "image" in dict_ and dict_["image"] is not None:
            instance.image = str(dict_["image"])
        elif include_empty:
            instance.image = ""
        if "instanceProvider" in dict_ and dict_["instanceProvider"] is not None:
            instance.instance_provider = str(dict_["instanceProvider"])
        elif include_empty:
            instance.instance_provider = ""
        if "isLocal" in dict_ and dict_["isLocal"] is not None:
            instance.is_local = bool(dict_["isLocal"])
        elif include_empty:
            instance.is_local = False
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "onDemand" in dict_ and dict_["onDemand"] is not None:
            instance.on_demand = bool(dict_["onDemand"])
        elif include_empty:
            instance.on_demand = False
        if "regions" in dict_ and dict_["regions"] is not None:
            instance.regions = [str(i0) for i0 in dict_["regions"]]
        elif include_empty:
            instance.regions = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiFleetListItemResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiFleetListItemResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiFleetListItemResponse,
        List[ApiFleetListItemResponse],
        Dict[Any, ApiFleetListItemResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "active": "active",
            "counts": "counts",
            "id": "id_",
            "image": "image",
            "instanceProvider": "instance_provider",
            "isLocal": "is_local",
            "name": "name",
            "onDemand": "on_demand",
            "regions": "regions",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "active": True,
            "counts": True,
            "id": True,
            "image": True,
            "instanceProvider": True,
            "isLocal": True,
            "name": True,
            "onDemand": True,
            "regions": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.time_zone import TimeZone
from ..models.time_zone_trans import TimeZoneTrans


class TimeLocation(Model):
    """Time location (time.Location)

    Properties:
        cache_end: (cacheEnd) REQUIRED int

        cache_start: (cacheStart) REQUIRED int

        cache_zone: (cacheZone) REQUIRED TimeZone

        extend: (extend) REQUIRED str

        name: (name) REQUIRED str

        tx: (tx) REQUIRED List[TimeZoneTrans]

        zone: (zone) REQUIRED List[TimeZone]
    """

    # region fields

    cache_end: int  # REQUIRED
    cache_start: int  # REQUIRED
    cache_zone: TimeZone  # REQUIRED
    extend: str  # REQUIRED
    name: str  # REQUIRED
    tx: List[TimeZoneTrans]  # REQUIRED
    zone: List[TimeZone]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_cache_end(self, value: int) -> TimeLocation:
        self.cache_end = value
        return self

    def with_cache_start(self, value: int) -> TimeLocation:
        self.cache_start = value
        return self

    def with_cache_zone(self, value: TimeZone) -> TimeLocation:
        self.cache_zone = value
        return self

    def with_extend(self, value: str) -> TimeLocation:
        self.extend = value
        return self

    def with_name(self, value: str) -> TimeLocation:
        self.name = value
        return self

    def with_tx(self, value: List[TimeZoneTrans]) -> TimeLocation:
        self.tx = value
        return self

    def with_zone(self, value: List[TimeZone]) -> TimeLocation:
        self.zone = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "cache_end"):
            result["cacheEnd"] = int(self.cache_end)
        elif include_empty:
            result["cacheEnd"] = 0
        if hasattr(self, "cache_start"):
            result["cacheStart"] = int(self.cache_start)
        elif include_empty:
            result["cacheStart"] = 0
        if hasattr(self, "cache_zone"):
            result["cacheZone"] = self.cache_zone.to_dict(include_empty=include_empty)
        elif include_empty:
            result["cacheZone"] = TimeZone()
        if hasattr(self, "extend"):
            result["extend"] = str(self.extend)
        elif include_empty:
            result["extend"] = ""
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "tx"):
            result["tx"] = [i0.to_dict(include_empty=include_empty) for i0 in self.tx]
        elif include_empty:
            result["tx"] = []
        if hasattr(self, "zone"):
            result["zone"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.zone
            ]
        elif include_empty:
            result["zone"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        cache_end: int,
        cache_start: int,
        cache_zone: TimeZone,
        extend: str,
        name: str,
        tx: List[TimeZoneTrans],
        zone: List[TimeZone],
        **kwargs,
    ) -> TimeLocation:
        instance = cls()
        instance.cache_end = cache_end
        instance.cache_start = cache_start
        instance.cache_zone = cache_zone
        instance.extend = extend
        instance.name = name
        instance.tx = tx
        instance.zone = zone
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> TimeLocation:
        instance = cls()
        if not dict_:
            return instance
        if "cacheEnd" in dict_ and dict_["cacheEnd"] is not None:
            instance.cache_end = int(dict_["cacheEnd"])
        elif include_empty:
            instance.cache_end = 0
        if "cacheStart" in dict_ and dict_["cacheStart"] is not None:
            instance.cache_start = int(dict_["cacheStart"])
        elif include_empty:
            instance.cache_start = 0
        if "cacheZone" in dict_ and dict_["cacheZone"] is not None:
            instance.cache_zone = TimeZone.create_from_dict(
                dict_["cacheZone"], include_empty=include_empty
            )
        elif include_empty:
            instance.cache_zone = TimeZone()
        if "extend" in dict_ and dict_["extend"] is not None:
            instance.extend = str(dict_["extend"])
        elif include_empty:
            instance.extend = ""
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "tx" in dict_ and dict_["tx"] is not None:
            instance.tx = [
                TimeZoneTrans.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["tx"]
            ]
        elif include_empty:
            instance.tx = []
        if "zone" in dict_ and dict_["zone"] is not None:
            instance.zone = [
                TimeZone.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["zone"]
            ]
        elif include_empty:
            instance.zone = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, TimeLocation]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[TimeLocation]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[TimeLocation, List[TimeLocation], Dict[Any, TimeLocation]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "cacheEnd": "cache_end",
            "cacheStart": "cache_start",
            "cacheZone": "cache_zone",
            "extend": "extend",
            "name": "name",
            "tx": "tx",
            "zone": "zone",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "cacheEnd": True,
            "cacheStart": True,
            "cacheZone": True,
            "extend": True,
            "name": True,
            "tx": True,
            "zone": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model

from ..models.api_artifact_sampling_rule import ApiArtifactSamplingRule


class ApiArtifactTypeSamplingRules(Model):
    """Api artifact type sampling rules (api.ArtifactTypeSamplingRules)

    Properties:
        crashed: (crashed) REQUIRED ApiArtifactSamplingRule

        success: (success) REQUIRED ApiArtifactSamplingRule

        unclaimed: (unclaimed) OPTIONAL ApiArtifactSamplingRule
    """

    # region fields

    crashed: ApiArtifactSamplingRule  # REQUIRED
    success: ApiArtifactSamplingRule  # REQUIRED
    unclaimed: ApiArtifactSamplingRule  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_crashed(
        self, value: ApiArtifactSamplingRule
    ) -> ApiArtifactTypeSamplingRules:
        self.crashed = value
        return self

    def with_success(
        self, value: ApiArtifactSamplingRule
    ) -> ApiArtifactTypeSamplingRules:
        self.success = value
        return self

    def with_unclaimed(
        self, value: ApiArtifactSamplingRule
    ) -> ApiArtifactTypeSamplingRules:
        self.unclaimed = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "crashed"):
            result["crashed"] = self.crashed.to_dict(include_empty=include_empty)
        elif include_empty:
            result["crashed"] = ApiArtifactSamplingRule()
        if hasattr(self, "success"):
            result["success"] = self.success.to_dict(include_empty=include_empty)
        elif include_empty:
            result["success"] = ApiArtifactSamplingRule()
        if hasattr(self, "unclaimed"):
            result["unclaimed"] = self.unclaimed.to_dict(include_empty=include_empty)
        elif include_empty:
            result["unclaimed"] = ApiArtifactSamplingRule()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        crashed: ApiArtifactSamplingRule,
        success: ApiArtifactSamplingRule,
        unclaimed: Optional[ApiArtifactSamplingRule] = None,
        **kwargs,
    ) -> ApiArtifactTypeSamplingRules:
        instance = cls()
        instance.crashed = crashed
        instance.success = success
        if unclaimed is not None:
            instance.unclaimed = unclaimed
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiArtifactTypeSamplingRules:
        instance = cls()
        if not dict_:
            return instance
        if "crashed" in dict_ and dict_["crashed"] is not None:
            instance.crashed = ApiArtifactSamplingRule.create_from_dict(
                dict_["crashed"], include_empty=include_empty
            )
        elif include_empty:
            instance.crashed = ApiArtifactSamplingRule()
        if "success" in dict_ and dict_["success"] is not None:
            instance.success = ApiArtifactSamplingRule.create_from_dict(
                dict_["success"], include_empty=include_empty
            )
        elif include_empty:
            instance.success = ApiArtifactSamplingRule()
        if "unclaimed" in dict_ and dict_["unclaimed"] is not None:
            instance.unclaimed = ApiArtifactSamplingRule.create_from_dict(
                dict_["unclaimed"], include_empty=include_empty
            )
        elif include_empty:
            instance.unclaimed = ApiArtifactSamplingRule()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiArtifactTypeSamplingRules]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiArtifactTypeSamplingRules]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiArtifactTypeSamplingRules,
        List[ApiArtifactTypeSamplingRules],
        Dict[Any, ApiArtifactTypeSamplingRules],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "crashed": "crashed",
            "success": "success",
            "unclaimed": "unclaimed",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "crashed": True,
            "success": True,
            "unclaimed": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: wrapper.j2

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import HeaderStr
from accelbyte_py_sdk.core import get_namespace as get_services_namespace
from accelbyte_py_sdk.core import run_request
from accelbyte_py_sdk.core import run_request_async
from accelbyte_py_sdk.core import same_doc_as


from ..operations.watchdogs import LocalWatchdogConnect
from ..operations.watchdogs import WatchdogConnect


@same_doc_as(LocalWatchdogConnect)
def local_watchdog_connect(
    watchdog_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """connect a local watchdog (LocalWatchdogConnect)

    This is to support local ds development scenarios

    Required Permission: NAMESPACE:{namespace}:AMS:LOCALDS [CREATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/local/{watchdogID}/connect

        method: GET

        tags: ["Watchdogs"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        watchdog_id: (watchdogID) REQUIRED str in path

    Responses:
        200: OK - (OK)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = LocalWatchdogConnect.create(
        watchdog_id=watchdog_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(LocalWatchdogConnect)
async def local_watchdog_connect_async(
    watchdog_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """connect a local watchdog (LocalWatchdogConnect)

    This is to support local ds development scenarios

    Required Permission: NAMESPACE:{namespace}:AMS:LOCALDS [CREATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/local/{watchdogID}/connect

        method: GET

        tags: ["Watchdogs"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        watchdog_id: (watchdogID) REQUIRED str in path

    Responses:
        200: OK - (OK)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = LocalWatchdogConnect.create(
        watchdog_id=watchdog_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(WatchdogConnect)
def watchdog_connect(
    watchdog_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """connect a watchdog (WatchdogConnect)

    Required Permission: NAMESPACE:{namespace}:ARMADA:WATCHDOG [CREATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/watchdogs/{watchdogID}/connect

        method: GET

        tags: ["Watchdogs"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        watchdog_id: (watchdogID) REQUIRED str in path

    Responses:
        200: OK - (OK)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = WatchdogConnect.create(
        watchdog_id=watchdog_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(WatchdogConnect)
async def watchdog_connect_async(
    watchdog_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """connect a watchdog (WatchdogConnect)

    Required Permission: NAMESPACE:{namespace}:ARMADA:WATCHDOG [CREATE]

    Properties:
        url: /ams/v1/namespaces/{namespace}/watchdogs/{watchdogID}/connect

        method: GET

        tags: ["Watchdogs"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        watchdog_id: (watchdogID) REQUIRED str in path

    Responses:
        200: OK - (OK)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = WatchdogConnect.create(
        watchdog_id=watchdog_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ApiDSHostConfiguration(Model):
    """Api DS host configuration (api.DSHostConfiguration)

    Properties:
        instance_id: (instanceId) REQUIRED str

        instance_provider: (instanceProvider) REQUIRED str

        instance_type: (instanceType) REQUIRED str

        servers_per_vm: (serversPerVm) REQUIRED int
    """

    # region fields

    instance_id: str  # REQUIRED
    instance_provider: str  # REQUIRED
    instance_type: str  # REQUIRED
    servers_per_vm: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_instance_id(self, value: str) -> ApiDSHostConfiguration:
        self.instance_id = value
        return self

    def with_instance_provider(self, value: str) -> ApiDSHostConfiguration:
        self.instance_provider = value
        return self

    def with_instance_type(self, value: str) -> ApiDSHostConfiguration:
        self.instance_type = value
        return self

    def with_servers_per_vm(self, value: int) -> ApiDSHostConfiguration:
        self.servers_per_vm = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "instance_id"):
            result["instanceId"] = str(self.instance_id)
        elif include_empty:
            result["instanceId"] = ""
        if hasattr(self, "instance_provider"):
            result["instanceProvider"] = str(self.instance_provider)
        elif include_empty:
            result["instanceProvider"] = ""
        if hasattr(self, "instance_type"):
            result["instanceType"] = str(self.instance_type)
        elif include_empty:
            result["instanceType"] = ""
        if hasattr(self, "servers_per_vm"):
            result["serversPerVm"] = int(self.servers_per_vm)
        elif include_empty:
            result["serversPerVm"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        instance_id: str,
        instance_provider: str,
        instance_type: str,
        servers_per_vm: int,
        **kwargs,
    ) -> ApiDSHostConfiguration:
        instance = cls()
        instance.instance_id = instance_id
        instance.instance_provider = instance_provider
        instance.instance_type = instance_type
        instance.servers_per_vm = servers_per_vm
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiDSHostConfiguration:
        instance = cls()
        if not dict_:
            return instance
        if "instanceId" in dict_ and dict_["instanceId"] is not None:
            instance.instance_id = str(dict_["instanceId"])
        elif include_empty:
            instance.instance_id = ""
        if "instanceProvider" in dict_ and dict_["instanceProvider"] is not None:
            instance.instance_provider = str(dict_["instanceProvider"])
        elif include_empty:
            instance.instance_provider = ""
        if "instanceType" in dict_ and dict_["instanceType"] is not None:
            instance.instance_type = str(dict_["instanceType"])
        elif include_empty:
            instance.instance_type = ""
        if "serversPerVm" in dict_ and dict_["serversPerVm"] is not None:
            instance.servers_per_vm = int(dict_["serversPerVm"])
        elif include_empty:
            instance.servers_per_vm = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiDSHostConfiguration]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiDSHostConfiguration]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiDSHostConfiguration,
        List[ApiDSHostConfiguration],
        Dict[Any, ApiDSHostConfiguration],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "instanceId": "instance_id",
            "instanceProvider": "instance_provider",
            "instanceType": "instance_type",
            "serversPerVm": "servers_per_vm",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "instanceId": True,
            "instanceProvider": True,
            "instanceType": True,
            "serversPerVm": True,
        }

    # endregion static methods
